@@ -22,18 +22,92 @@ from calculate.lib.cl_lang import setLocalTranslate
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
 
-class FileSystemManager(object):
+class FileSystemManager():
     """Convert dict install option"""
 
     defaultOpt = ['noatime']
     defaultBindOpts = ['bind']
+    #Python3 compat problem:
+    # dict keys() now sorted based on insertion order,
+    # instead of being sorted arbitrary by hash.
+    # Just so the order of keys could be the same as 
+    # in older version, I swaped some pairs around.
     supportFS = {
-        'ext2': {'defaultopt': defaultOpt,
-                 'format': '/sbin/mkfs.ext2',
+        'f2fs': {'defaultopt': defaultOpt,
+                'format': '/usr/sbin/mkfs.f2fs',
+                'formatparam': '{labelparam} -f {device}',
+                'gpt': '8300',
+                'label': '-l {labelname}',
+                'msdos': '83',
+                'ssd': [],
+                'compress': None,
+                'type': ['hdd', 'usb-hdd']},
+        'btrfs': {'defaultopt': defaultOpt,
+                  'format': '/sbin/mkfs.btrfs',
+                  'formatparam': '{labelparam} -f {device}',
+                  'gpt': '8300',
+                  'label': '-L {labelname}',
+                  'msdos': '83',
+                  'ssd': ['ssd', 'discard', 'space_cache'],
+                  'type': ['hdd', 'usb-hdd'],
+                  'compress': None,
+                  'compatible': ['btrfs-compress']},
+        'ntfs-3g': {'defaultopt': defaultOpt,
+                    'format': '/usr/sbin/mkfs.ntfs',
+                    'formatparam': '{labelparam} -FQ {device}',
+                    'gpt': '8300',
+                    'label': '-L {labelname}',
+                    'ssd': [],
+                    'auto': False,
+                    'msdos': '7',
+                    'compress': None,
+                    'compatible': ['ntfs']},
+        'ntfs': {'defaultopt': defaultOpt,
+                 'format': '/usr/sbin/mkfs.ntfs',
+                 'formatparam': '{labelparam} -FQ {device}',
+                 'gpt': '8300',
+                 'label': '-L {labelname}',
+                 'msdos': '7',
+                 'auto': False,
+                 'ssd': [],
+                 'compress': None,
+                 'compatible': ['ntfs-3g']},
+        'reiserfs': {'defaultopt': defaultOpt,
+                     'format': '/sbin/mkfs.reiserfs',
+                     'formatparam': '{labelparam} -f {device}',
+                     'gpt': '8300',
+                     'label': '-l {labelname}',
+                     'msdos': '83',
+                     'compress': None,
+                     'ssd': [],
+                     'type': ['hdd', 'usb-hdd']},
+        'xfs': {'defaultopt': defaultOpt,
+                'format': '/sbin/mkfs.xfs',
+                'formatparam': '{labelparam} -f {device}',
+                'gpt': '8300',
+                'label': '-L {labelname}',
+                'msdos': '83',
+                'boot': '-i sparce=0',
+                'ssd': ['discard'],
+                'compress': None,
+                'type': ['hdd', 'usb-hdd']},
+        'btrfs-compress': {'defaultopt': defaultOpt,
+                  'format': '/sbin/mkfs.btrfs',
+                  'orig': 'btrfs',
+                  'compress': "compress=%s",
+                  'formatparam': '{labelparam} -f {device}',
+                  'gpt': '8300',
+                  'label': '-L {labelname}',
+                  'msdos': '83',
+                  'ssd': ['ssd', 'discard', 'space_cache'],
+                  'type': ['hdd', 'usb-hdd'],
+                  'compatible': ['btrfs']},
+        'ext4': {'defaultopt': defaultOpt,
+                 'format': '/sbin/mkfs.ext4',
                  'formatparam': '{labelparam} {device}',
                  'gpt': '8300',
                  'label': '-L {labelname}',
-                 'ssd': [],
+                 'ssd': ['discard'],
                  'msdos': '83',
                  'compress': None,
                  'type': ['hdd', 'usb-hdd']},
@@ -46,90 +120,15 @@ class FileSystemManager(object):
                  'msdos': '83',
                  'compress': None,
                  'type': ['hdd', 'usb-hdd']},
-        'ext4': {'defaultopt': defaultOpt,
-                 'format': '/sbin/mkfs.ext4',
+        'ext2': {'defaultopt': defaultOpt,
+                 'format': '/sbin/mkfs.ext2',
                  'formatparam': '{labelparam} {device}',
                  'gpt': '8300',
                  'label': '-L {labelname}',
-                 'ssd': ['discard'],
+                 'ssd': [],
                  'msdos': '83',
                  'compress': None,
                  'type': ['hdd', 'usb-hdd']},
-        'reiserfs': {'defaultopt': defaultOpt,
-                     'format': '/sbin/mkfs.reiserfs',
-                     'formatparam': '{labelparam} -f {device}',
-                     'gpt': '8300',
-                     'label': '-l {labelname}',
-                     'msdos': '83',
-                     'compress': None,
-                     'ssd': [],
-                     'type': ['hdd', 'usb-hdd']},
-        'btrfs': {'defaultopt': defaultOpt,
-                  'format': '/sbin/mkfs.btrfs',
-                  'formatparam': '{labelparam} -f {device}',
-                  'gpt': '8300',
-                  'label': '-L {labelname}',
-                  'msdos': '83',
-                  'ssd': ['ssd', 'discard', 'space_cache'],
-                  'type': ['hdd', 'usb-hdd'],
-                  'compress': None,
-                  'compatible': ['btrfs-compress']},
-        'btrfs-compress': {'defaultopt': defaultOpt,
-                  'format': '/sbin/mkfs.btrfs',
-                  'orig': 'btrfs',
-                  'compress': "compress=%s",
-                  'formatparam': '{labelparam} -f {device}',
-                  'gpt': '8300',
-                  'label': '-L {labelname}',
-                  'msdos': '83',
-                  'ssd': ['ssd', 'discard', 'space_cache'],
-                  'type': ['hdd', 'usb-hdd'],
-                  'compatible': ['btrfs']},
-        'jfs': {'defaultopt': defaultOpt,
-                'format': '/sbin/mkfs.jfs',
-                'formatparam': '{labelparam} -f {device}',
-                'gpt': '8300',
-                'label': '-L {labelname}',
-                'msdos': '83',
-                'ssd': ['discard'],
-                'compress': None,
-                'type': ['hdd', 'usb-hdd']},
-        'xfs': {'defaultopt': defaultOpt,
-                'format': '/sbin/mkfs.xfs',
-                'formatparam': '{labelparam} -f {device}',
-                'gpt': '8300',
-                'label': '-L {labelname}',
-                'msdos': '83',
-                'boot': '-i sparce=0',
-                'ssd': ['discard'],
-                'compress': None,
-                'type': ['hdd', 'usb-hdd']},
-        'f2fs': {'defaultopt': defaultOpt,
-                'format': '/usr/sbin/mkfs.f2fs',
-                'formatparam': '{labelparam} -f {device}',
-                'gpt': '8300',
-                'label': '-l {labelname}',
-                'msdos': '83',
-                'ssd': [],
-                'compress': None,
-                'type': ['hdd', 'usb-hdd']},
-#        'nilfs2': {'defaultopt': defaultOpt,
-#                   'format': '/sbin/mkfs.nilfs2',
-#                   'formatparam': '{labelparam} {device}',
-#                   'gpt': '8300',
-#                   'label': '-L {labelname}',
-#                   'msdos': '83',
-#                   'ssd': [],
-#                   'type': ['hdd', 'usb-hdd']},
-        'swap': {'defaultopt': ['sw'],
-                 'format': '/sbin/mkswap',
-                 'formatparam': '{device}',
-                 'gpt': '8200',
-                 'label': '',
-                 'ssd': [],
-                 'auto': False,
-                 'compress': None,
-                 'msdos': '82'},
         'uefi': {'defaultopt': defaultOpt,
                  'format': '/usr/sbin/mkfs.vfat',
                  'formatparam': '{labelparam} -F 32 {device}',
@@ -150,26 +149,33 @@ class FileSystemManager(object):
                  'ssd': ['discard'],
                  'compress': None,
                  'type': ['flash']},
-        'ntfs': {'defaultopt': defaultOpt,
-                 'format': '/usr/sbin/mkfs.ntfs',
-                 'formatparam': '{labelparam} -FQ {device}',
-                 'gpt': '8300',
-                 'label': '-L {labelname}',
-                 'msdos': '7',
-                 'auto': False,
+        'jfs': {'defaultopt': defaultOpt,
+                'format': '/sbin/mkfs.jfs',
+                'formatparam': '{labelparam} -f {device}',
+                'gpt': '8300',
+                'label': '-L {labelname}',
+                'msdos': '83',
+                'ssd': ['discard'],
+                'compress': None,
+                'type': ['hdd', 'usb-hdd']},
+#        'nilfs2': {'defaultopt': defaultOpt,
+#                   'format': '/sbin/mkfs.nilfs2',
+#                   'formatparam': '{labelparam} {device}',
+#                   'gpt': '8300',
+#                   'label': '-L {labelname}',
+#                   'msdos': '83',
+#                   'ssd': [],
+#                   'type': ['hdd', 'usb-hdd']},
+        'swap': {'defaultopt': ['sw'],
+                 'format': '/sbin/mkswap',
+                 'formatparam': '{device}',
+                 'gpt': '8200',
+                 'label': '',
                  'ssd': [],
+                 'auto': False,
                  'compress': None,
-                 'compatible': ['ntfs-3g']},
-        'ntfs-3g': {'defaultopt': defaultOpt,
-                    'format': '/usr/sbin/mkfs.ntfs',
-                    'formatparam': '{labelparam} -FQ {device}',
-                    'gpt': '8300',
-                    'label': '-L {labelname}',
-                    'ssd': [],
-                    'auto': False,
-                    'msdos': '7',
-                    'compress': None,
-                    'compatible': ['ntfs']}}
+                 'msdos': '82'},
+        }
 
     default_param = {'defaultopt': defaultOpt,
                      'gpt': '8300',
